==> exo.jcr.component.ext-1.9.3-sources.jar: org/exoplatform/services/jcr/ext/hierarchy/impl/AddPathPlugin.java <==
/*
 * Copyright (C) 2003-2007 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 */
package org.exoplatform.services.jcr.ext.hierarchy.impl;

import org.exoplatform.container.component.BaseComponentPlugin;
import org.exoplatform.container.xml.InitParams;

/**
 * Created by The eXo Platform SAS
 * Author : Dang Van Minh
 *          minh.dang@exoplatform.com
 * Nov 15, 2007 2:49:30 PM
 */
public class AddPathPlugin extends BaseComponentPlugin {

  private HierarchyConfig paths;
  private String description;
  private String name;

  public AddPathPlugin(InitParams params) {
    paths = (HierarchyConfig) params.getObjectParamValues(HierarchyConfig.class).get(0);
  }
  
  public HierarchyConfig getPaths() {
    return paths;
  }

  public String getName() {   return name; }
  public void setName(String s) { name = s ; }

  public String getDescription() {   return description ; }
  public void setDescription(String s) { description = s ;  }

}

==> exo.jcr.component.ext-1.10.3-sources.jar: org/exoplatform/services/jcr/ext/hierarchy/impl/AddPathPlugin.java <==
/*
 * Copyright (C) 2003-2007 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 */
package org.exoplatform.services.jcr.ext.hierarchy.impl;

import org.exoplatform.container.component.BaseComponentPlugin;
import org.exoplatform.container.xml.InitParams;

/**
 * Created by The eXo Platform SAS Author : Dang Van Minh minh.dang@exoplatform.com Nov 15, 2007
 * 2:49:30 PM
 */
public class AddPathPlugin extends BaseComponentPlugin {

  private HierarchyConfig paths;

  private String          description;

  private String          name;

  public AddPathPlugin(InitParams params) {
    paths = (HierarchyConfig) params.getObjectParamValues(HierarchyConfig.class).get(0);
  }

  public HierarchyConfig getPaths() {
    return paths;
  }

  public String getName() {
    return name;
  }

  public void setName(String s) {
    name = s;
  }

  public String getDescription() {
    return description;
  }

  public void setDescription(String s) {
    description = s;
  }

}
